ANSIColors class abstract

Constructors

ANSIColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

black → const ANSIColor
blue → const ANSIColor
brightBlack → const ANSIColor
brightBlue → const ANSIColor
brightCyan → const ANSIColor
brightGreen → const ANSIColor
brightMagenta → const ANSIColor
brightRed → const ANSIColor
brightWhite → const ANSIColor
brightYellow → const ANSIColor
cyan → const ANSIColor
green → const ANSIColor
magenta → const ANSIColor
red → const ANSIColor
white → const ANSIColor
yellow → const ANSIColor