Echo class

Constructors

Echo({LogLevel level = LogLevel.all, LogFormatter formatter = const LogFormatter(errorColors: ANSIColors.red, debugColors: ANSIColors.green, infoColors: ANSIColors.blue, warningColors: ANSIColors.yellow)})

Properties

formatter LogFormatter
final
hashCode int
The hash code for this object.
no setterinherited
level LogLevel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

d(String message, {String tag = 'Echo', DateTime? time, Object? error, StackTrace? stackTrace}) → void
e(String message, {String tag = 'Echo', DateTime? time, Object? error, StackTrace? stackTrace}) → void
i(String message, {String tag = 'Echo', DateTime? time, Object? error, StackTrace? stackTrace}) → void
log(dynamic message, {required LogLevel logLevel, String tag = 'Echo', DateTime? time, Object? error, StackTrace? stackTrace}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
w(String message, {String tag = 'Echo', DateTime? time, Object? error, StackTrace? stackTrace}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited