LogFormatter class
Constructors
- LogFormatter({required ANSIColor errorColors, required ANSIColor debugColors, required ANSIColor infoColors, required ANSIColor warningColors})
-
const
Properties
- columns → int
-
final
- debugColors → ANSIColor
-
final
- errorColors → ANSIColor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- infoColors → ANSIColor
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warningColors → ANSIColor
-
final
Methods
-
decorateMessage(
String formattedMessage, LogLevel logLevel, String tag, DateTime? time, String? formattedError, String? formattedStackTrace) → List< LogLine> -
format(
dynamic message, {required LogLevel logLevel, required String tag, DateTime? time, Object? error, StackTrace? stackTrace}) → List< LogLine> -
formatError(
Object error) → String -
formatMessage(
dynamic message) → String -
formatStackTrace(
StackTrace stackTrace) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited